# SCAPE
[![Stars](https://img.shields.io/github/stars/ericli0419/SCAPE?logo=GitHub&color=yellow)](https://github.com/ericli0419/SCAPE) [![PyPI](https://img.shields.io/pypi/v/scape-sc.svg)](https://pypi.org/project/scape-sc)

## Installation  	
#### install from GitHub

	git clone https://github.com/ericli0419/SCAPE.git
	cd SCAPE
	python setup.py install

SCAPE is implemented in [Pytorch](https://pytorch.org/) framework.  
SCAPE can be run on CPU devices, and running SCAPE on GPU devices if available is recommended.  
